========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/octavia.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

=======
Octavia
=======

.. image:: https://img.shields.io/pypi/v/octavia.svg
    :target: https://pypi.org/project/octavia/
    :alt: Latest Version

Octavia is an operator-grade open source scalable load balancer for use in
large OpenStack deployments. It delivers load balancing services on `amphorae
<https://docs.openstack.org/octavia/latest/reference/glossary.html>`_ and
provides centralized command and control. Octavia is currently the reference
backend for Neutron LBaaS. In the near future, Octavia is likely to become the
standard OpenStack LBaaS API endpoint.

Octavia is distributed under the terms of the Apache License, Version 2.0.
The full terms and conditions of this license are detailed in the LICENSE
file.

Project resources
~~~~~~~~~~~~~~~~~

Developer documentation for the Octavia project is available at
https://docs.openstack.org/octavia/latest/

Release notes for the Octavia project are available at
https://docs.openstack.org/releasenotes/octavia/

The project source code repository is located at
https://git.openstack.org/cgit/openstack/octavia

Project status, bugs, and requests for feature enhancements are tracked on
https://storyboard.openstack.org/#!/project/openstack/octavia

For more information on project direction and guiding principles for
contributors, please see the CONSTITUTION.rst file in this directory, or
specifications in the specs/ sub-directory.

The project roadmap is available at
https://wiki.openstack.org/wiki/Octavia/Roadmap

External Resources
~~~~~~~~~~~~~~~~~~

* Octavia Wiki: https://wiki.openstack.org/wiki/Octavia

* For help on usage and hacking of Octavia, please send an email to
  OpenStack-dev Mailing List <mailto:openstack-discuss@lists.openstack.org>
  with **[Octavia]** tag.
